@@ -2,7 +2,7 @@
  * File: launch.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: launch.c 7726 2006-01-06 01:08:10Z jdorje $
+ * $Id: launch.c 8615 2006-10-04 02:37:04Z jdorje $
  *
  * Code for launching games through the GTK client
  *
@@ -100,7 +100,7 @@ void launch_create_or_raise(void)
 static void launch_fill_defaults(GtkWidget * widget, gpointer data)
 {
 	GtkWidget *tmp;
-	gchar *text, *seatstring;
+	gchar *text;
 	GGZRoom *room;
 	GGZGameType *gt;
 	GList *items = NULL;
@@ -162,15 +162,25 @@ static void launch_fill_defaults(GtkWidget * widget, gpointer data)
 
 	/* If bots are allowed, default to bot players, otherwise open */
 	maxbots = ggzcore_gametype_get_max_bots(gt);
-	if (maxbots > 0)
-		seatstring = "seat%d_bot";
-	else
-		seatstring = "seat%d_open";
+
+	if (maxbots < maxplayers) {
+		tmp = ggz_lookup_widget(launch_dialog, "seat1_bot");
+		gtk_widget_set_sensitive(GTK_WIDGET(tmp), FALSE);
+	}
 
 	for (x = 2; x <= maxplayers; x++) {
 		char text[128];
-		sprintf(text, seatstring, x);
-		tmp = lookup_widget(launch_dialog, text);
+
+		if (maxbots >= x - 1) {
+			snprintf(text, sizeof(text), "seat%d_bot", x);
+		} else {
+			snprintf(text, sizeof(text), "seat%d_bot", x);
+			tmp = ggz_lookup_widget(launch_dialog, text);
+			gtk_widget_set_sensitive(GTK_WIDGET(tmp), FALSE);
+
+			snprintf(text, sizeof(text), "seat%d_open", x);
+		}
+		tmp = ggz_lookup_widget(launch_dialog, text);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp), TRUE);
 	}
 }
@@ -192,13 +202,13 @@ static void launch_seats_changed(GtkWidget * widget, gpointer data)
 	   sensitize others */
 	for (i = 1; i <= seats; i++) {
 		char text[128];
-		sprintf(text, "seat%d_box", i);
+		snprintf(text, sizeof(text), "seat%d_box", i);
 		tmp = g_object_get_data(G_OBJECT(launch_dialog), text);
 		gtk_widget_set_sensitive(tmp, TRUE);
 	}
 	for (i = (seats + 1); i <= max; i++) {
 		char text[128];
-		sprintf(text, "seat%d_box", i);
+		snprintf(text, sizeof(text), "seat%d_box", i);
 		tmp = g_object_get_data(G_OBJECT(launch_dialog), text);
 		gtk_widget_set_sensitive(tmp, FALSE);
 	}
@@ -235,34 +245,34 @@ void launch_table(void)
 	if (!launch_dialog)
 		ggz_error_msg("Trying to launch table when "
 			      "there is no launch dialog.");
-	tmp = lookup_widget(launch_dialog, "seats_combo");
+	tmp = ggz_lookup_widget(launch_dialog, "seats_combo");
 	seats = atoi(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(tmp)->entry)));
 
 	/* Create a table for sending to the server */
 	table = ggzcore_table_new();
 	room = ggzcore_server_get_cur_room(server);
 	gt = ggzcore_room_get_gametype(room);
-	tmp = lookup_widget(launch_dialog, "desc_entry");
+	tmp = ggz_lookup_widget(launch_dialog, "desc_entry");
 	ggzcore_table_init(table, gt, gtk_entry_get_text(GTK_ENTRY(tmp)),
 			   seats);
 
 	for (x = 0; x < seats; x++) {
 		/* Check to see if the seat is a bot. */
 		char text[128];
-		sprintf(text, "seat%d_bot", x + 1);
-		tmp = lookup_widget(launch_dialog, text);
+		snprintf(text, sizeof(text), "seat%d_bot", x + 1);
+		tmp = ggz_lookup_widget(launch_dialog, text);
 		if (GTK_TOGGLE_BUTTON(tmp)->active)
 			if (ggzcore_table_set_seat(table, x,
 						   GGZ_SEAT_BOT, NULL) < 0)
 				assert(0);
 
 		/* Check to see if the seat is reserved. */
-		sprintf(text, "seat%d_resv", x + 1);
-		tmp = lookup_widget(launch_dialog, text);
+		snprintf(text, sizeof(text), "seat%d_resv", x + 1);
+		tmp = ggz_lookup_widget(launch_dialog, text);
 		if (GTK_TOGGLE_BUTTON(tmp)->active) {
 			const gchar *name;
-			sprintf(text, "seat%d_name", x + 1);
-			tmp = lookup_widget(launch_dialog, text);
+			snprintf(text, sizeof(text), "seat%d_name", x + 1);
+			tmp = ggz_lookup_widget(launch_dialog, text);
 			name = gtk_entry_get_text(GTK_ENTRY(tmp));
 
 			if (ggzcore_table_set_seat(table, x,
@@ -295,15 +305,15 @@ static void launch_start_game(GtkWidget * widget, gpointer data)
 	gint x, seats, bots;
 
 	/* Grab the number of seats */
-	tmp = lookup_widget(launch_dialog, "seats_combo");
+	tmp = ggz_lookup_widget(launch_dialog, "seats_combo");
 	seats = atoi(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(tmp)->entry)));
 
 	/* Let's go bot counting.... */
 	bots = 0;
 	for (x = 0; x < seats; x++) {
 		char text[128];
-		sprintf(text, "seat%d_bot", x + 1);
-		tmp = lookup_widget(launch_dialog, text);
+		snprintf(text, sizeof(text), "seat%d_bot", x + 1);
+		tmp = ggz_lookup_widget(launch_dialog, text);
 		if (GTK_TOGGLE_BUTTON(tmp)->active)
 			bots++;
 	}
@@ -343,7 +353,7 @@ static void launch_seat_show(gint seat, gchar show)
 	char text[128];
 
 	/* Show seat's hbox */
-	sprintf(text, "seat%d_box", seat);
+	snprintf(text, sizeof(text), "seat%d_box", seat);
 	tmp = g_object_get_data(G_OBJECT(launch_dialog), text);
 	if (show)
 		gtk_widget_show(GTK_WIDGET(tmp));
@@ -405,7 +415,7 @@ GtkWidget *create_dlg_launch(void)
 
 	dlg_launch = gtk_dialog_new();
 	gtk_window_set_transient_for(GTK_WINDOW(dlg_launch),
-				     GTK_WINDOW(win_main));
+				     GTK_WINDOW(main_window));
 	g_object_set_data(G_OBJECT(dlg_launch), "dlg_launch", dlg_launch);
 	gtk_window_set_title(GTK_WINDOW(dlg_launch), _("Seat Assignments"));
 	gtk_window_set_resizable(GTK_WINDOW(dlg_launch), TRUE);
@@ -565,7 +575,7 @@ GtkWidget *create_dlg_launch(void)
 
 		seats[i].box = gtk_hbox_new(FALSE, 0);
 		gtk_widget_ref(seats[i].box);
-		sprintf(text, "seat%d_box", i + 1);
+		snprintf(text, sizeof(text), "seat%d_box", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].box,
 					 (GtkDestroyNotify) gtk_widget_unref);
@@ -573,10 +583,10 @@ GtkWidget *create_dlg_launch(void)
 		gtk_box_pack_start(GTK_BOX(seat_box), seats[i].box, FALSE,
 				   FALSE, 0);
 
-		sprintf(text, _("Seat %d:"), i + 1);
+		snprintf(text, sizeof(text), _("Seat %d:"), i + 1);
 		seats[i].label = gtk_label_new(text);
 		gtk_widget_ref(seats[i].label);
-		sprintf(text, "seat%d_lable", i + 1);
+		snprintf(text, sizeof(text), "seat%d_lable", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].label,
 					 (GtkDestroyNotify) gtk_widget_unref);
@@ -590,7 +600,7 @@ GtkWidget *create_dlg_launch(void)
 			gtk_radio_button_get_group(GTK_RADIO_BUTTON
 					       (seats[i].bot));
 		gtk_widget_ref(seats[i].bot);
-		sprintf(text, "seat%d_bot", i + 1);
+		snprintf(text, sizeof(text), "seat%d_bot", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].bot,
 					 (GtkDestroyNotify) gtk_widget_unref);
@@ -605,7 +615,7 @@ GtkWidget *create_dlg_launch(void)
 			gtk_radio_button_get_group(GTK_RADIO_BUTTON
 					       (seats[i].open));
 		gtk_widget_ref(seats[i].open);
-		sprintf(text, "seat%d_open", i + 1);
+		snprintf(text, sizeof(text), "seat%d_open", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].open,
 					 (GtkDestroyNotify) gtk_widget_unref);
@@ -620,7 +630,7 @@ GtkWidget *create_dlg_launch(void)
 			gtk_radio_button_get_group(GTK_RADIO_BUTTON
 					       (seats[i].resv));
 		gtk_widget_ref(seats[i].resv);
-		sprintf(text, "seat%d_resv", i + 1);
+		snprintf(text, sizeof(text), "seat%d_resv", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].resv,
 					 (GtkDestroyNotify) gtk_widget_unref);
@@ -634,7 +644,7 @@ GtkWidget *create_dlg_launch(void)
 		gtk_entry_set_max_length(GTK_ENTRY(seats[i].name),
 					 MAX_RESERVED_NAME_LEN);
 		gtk_widget_ref(seats[i].name);
-		sprintf(text, "seat%d_name", i + 1);
+		snprintf(text, sizeof(text), "seat%d_name", i + 1);
 		g_object_set_data_full(G_OBJECT(dlg_launch), text,
 					 seats[i].name,
 					 (GtkDestroyNotify) gtk_widget_unref);
