@@ -3,7 +3,7 @@
  * Author: GGZ Dev Team
  * Project: GGZ GTK Client
  * Date: 11/03/2002
- * $Id: playerlist.h,v 1.1 2002/11/04 01:47:47 jdorje Exp $
+ * $Id: playerlist.h 7757 2006-01-09 18:03:06Z jdorje $
  * 
  * List of players in the current room
  * 
@@ -24,6 +24,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-void display_players(void);
+#include <gtk/gtk.h>
 
-GtkWidget *create_player_list(GtkWidget * window);
+void sensitize_player_list(gboolean sensitive);
+void clear_player_list(void);
+void update_player_list(void);
+
+GtkWidget *create_player_list(GtkWidget *window);
